<?php
/**
 * elecrix functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package elecrix
 */

/**
 * Define Core File
*/
define( 'ELECRIX_THEME_DRI', get_template_directory() );
define( 'ELECRIX_THEME_URI', get_template_directory_uri() );
define( 'ELECRIX_CSS_PATH', ELECRIX_THEME_URI . '/assets/css' );
define( 'ELECRIX_JS_PATH', ELECRIX_THEME_URI . '/assets/js' );
define( 'ELECRIX_ICON_PATH', ELECRIX_THEME_URI . '/assets/fonts/fontawesome/css' );
define( 'ELECRIX_IMG_PATH', ELECRIX_THEME_URI . '/assets/images' );

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function elecrix_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on elecrix, use a find and replace
		* to change 'elecrix' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'elecrix', get_template_directory() . '/languages' );
	remove_theme_support( 'widgets-block-editor' );

	// custom image size
	add_image_size( 'elecrix-img-size-1', 370, 270, true );
	add_image_size( 'elecrix-img-size-2', 310, 415, true );
	add_image_size( 'elecrix-img-size-3', 816, 357, true );

	//Woocommerce Support
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'elecrix' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'elecrix_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'elecrix_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function elecrix_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'elecrix_content_width', 640 );
}
add_action( 'after_setup_theme', 'elecrix_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function elecrix_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'elecrix' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'elecrix' ),
			'before_widget' => '<section id="%1$s" class="widget elx-blog-widget ul-li-block %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer One', 'elecrix' ),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'Add Footer widgets here.', 'elecrix' ),
			'before_widget' => '<div id="%1$s" class="elx-footer-widget headline pera-content ul-li-block"><div class="menu-widget">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Two', 'elecrix' ),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'Add Footer widgets here.', 'elecrix' ),
			'before_widget' => '<div id="%1$s" class="elx-footer-widget headline pera-content ul-li-block"><div class="menu-widget">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	
}
add_action( 'widgets_init', 'elecrix_widgets_init' );



/**
 *Google Font Load 
 */
if ( ! function_exists( 'elecrix_fonts_url' ) ) :
	
function elecrix_fonts_url() {
	$fonts_url     = '';
	$font_families = array();
	$subsets       = 'latin';


	if ( 'off' !== _x( 'on', 'Inter: on or off', 'elecrix' ) ) {
		$font_families[] = 'Inter:100,200,300,400,500,600,700,800,900';
	}

	if ( $font_families ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}
endif;

/**
 * Enqueue scripts and styles.
 */
function elecrix_scripts() {
	// elecrix Font Load
	wp_enqueue_style( 'elecrix-google-fonts', elecrix_fonts_url(), array(), null );

	wp_enqueue_style( 'bootstrap', ELECRIX_CSS_PATH . '/bootstrap.min.css' );
	wp_enqueue_style( 'fontawesome-all-1', ELECRIX_CSS_PATH . '/fontawesome-all.css' );
	wp_enqueue_style( 'flaticon', ELECRIX_CSS_PATH . '/flaticon.css' );
	wp_enqueue_style( 'splitting', ELECRIX_CSS_PATH . '/splitting.css' );
	wp_enqueue_style( 'animate', ELECRIX_CSS_PATH . '/animate.css' );
	wp_enqueue_style( 'video', ELECRIX_CSS_PATH . '/video.min.css' );
	wp_enqueue_style( 'slick-theme', ELECRIX_CSS_PATH . '/slick-theme.css' );
	wp_enqueue_style( 'slick', ELECRIX_CSS_PATH . '/slick.css' );
	wp_enqueue_style( 'global', ELECRIX_CSS_PATH . '/global.css' );
	wp_enqueue_style( 'odometer-theme-default', ELECRIX_CSS_PATH . '/odometer-theme-default.css' );
	wp_enqueue_style( 'elecrix-main', ELECRIX_CSS_PATH . '/style.css' );

	if(class_exists('WooCommerce')){
		wp_enqueue_style( 'bizex-woocommerce', ELECRIX_CSS_PATH . '/woocommerce.css' );
	}

	wp_enqueue_style( 'elecrix-style', get_stylesheet_uri(), array(), );

	wp_enqueue_script('masonry');
	wp_enqueue_script( 'bootstrap', ELECRIX_JS_PATH . '/bootstrap.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'popper', ELECRIX_JS_PATH . '/popper.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'appear', ELECRIX_JS_PATH . '/appear.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'slick', ELECRIX_JS_PATH . '/slick.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'wow', ELECRIX_JS_PATH . '/wow.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'rbtools', ELECRIX_JS_PATH . '/rbtools.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'twin', ELECRIX_JS_PATH . '/twin.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'odometer', ELECRIX_JS_PATH . '/odometer.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'splitting', ELECRIX_JS_PATH . '/splitting.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'scroll-out', ELECRIX_JS_PATH . '/scroll-out.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'parallax-scroll', ELECRIX_JS_PATH . '/parallax-scroll.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'jquery-magnific-popup', ELECRIX_JS_PATH . '/jquery.magnific-popup.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'script', ELECRIX_JS_PATH . '/script.js', array('jquery'), '1.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'elecrix_scripts' );

/**
 * Implement the Custom Header feature.
 */
require ELECRIX_THEME_DRI . '/inc/custom-header.php';

/**
 * Nav Walker
 */
require ELECRIX_THEME_DRI . '/inc/class-wp-elecrix-navwalker.php';

/**
 * Custom template tags for this theme.
 */
require ELECRIX_THEME_DRI . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require ELECRIX_THEME_DRI . '/inc/template-functions.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require ELECRIX_THEME_DRI . '/lib/plugin-activation.php';

/**
 * Oneclick Demo Import
 */
require ELECRIX_THEME_DRI . '/lib/ocdi/functions.php';

/**
 * Customizer additions.
 */
require ELECRIX_THEME_DRI . '/inc/customizer.php';

/**
 * Dynamic Css
 */
require ELECRIX_THEME_DRI . '/inc/dynamic-style.php';

/**
 * elecrix Functions
 */
require ELECRIX_THEME_DRI . '/inc/elecrix-functions.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require ELECRIX_THEME_DRI . '/inc/jetpack.php';
}


/**
 * elecrix Functions
 */
require ELECRIX_THEME_DRI . '/inc/cs-framework-functions.php';

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328810&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        