<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package elecrix
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function elecrix_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'elecrix_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function elecrix_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'elecrix_pingback_header' );

/**
 * Authore Avater
 */
function elecrix_main_author_avatars($size) {
    echo get_avatar(get_the_author_meta('email'), $size);
}
  
add_action('genesis_entry_header', 'elecrix_post_author_avatars');


/**
 * elecrix Single Post Nav
 */
function elecrix_single_post_pagination(){ 
    $elecrix_prev_post = get_previous_post();
    $elecrix_next_post = get_next_post();
?>
<div class="bz-project-next-prev-btn d-flex text-uppercase justify-content-between">
	<a href="<?php echo esc_url(get_the_permalink($elecrix_prev_post));?>"><i class="far fa-long-arrow-left"></i> <?php esc_html_e('Previous Post', 'elecrix');?></a>
	<a href="<?php echo esc_url(get_the_permalink($elecrix_next_post));?>"><?php esc_html_e('Next Post', 'elecrix');?> <i class="far fa-long-arrow-right"></i></a>
</div>
<?php 
}



/**
 * Comment Message Box
 */
function elecrix_comment_reform( $arg ) {

	$arg['title_reply']   = esc_html__( 'Leave a comment', 'elecrix' );
	$arg['comment_field'] = '<div class="row"><div class="col-md-12"><div class="input-field mb-30"><textarea id="comment" class="form_control" name="comment" cols="77" rows="3" placeholder="' . esc_attr__( "Comment", "elecrix" ) . '" aria-required="true"></textarea></div></div></div>';

	return $arg;

}
add_filter( 'comment_form_defaults', 'elecrix_comment_reform' );


/**
 * Comment Form Field
 */
function elecrix_modify_comment_form_fields( $fields ) {
	$commenter = wp_get_current_commenter();
	$req       = get_option( 'require_name_email' );

	$fields['author'] = '<div class="row"><div class="col-md-4"><div class="input-field mb-30"><input type="text" name="author" id="author" value="' . esc_attr( $commenter['comment_author'] ) . '" placeholder="' . esc_attr__( "Name", "elecrix" ) . '" size="22" tabindex="1"' . ( $req ? 'aria-required="true"' : '' ) . ' class="form_control" /></div></div>';

	$fields['email'] = '<div class="col-md-4"><div class="input-field mb-30"><input type="email" name="email" id="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" placeholder="' . esc_attr__( "Email", "elecrix" ) . '" size="22" tabindex="2"' . ( $req ? 'aria-required="true"' : '' ) . ' class="form_control"  /></div></div>';

	$fields['url'] = '<div class="col-md-4"><div class="input-field mb-30"><input type="url" name="url" id="url" value="' . esc_attr( $commenter['comment_author_url'] ) . '" placeholder="' . esc_attr__( "Website", "elecrix" ) . '" size="22" tabindex="2"' . ( $req ? 'aria-required="false"' : '' ) . ' class="form_control"  /></div></div></div>';

	return $fields;
}
add_filter( 'comment_form_default_fields', 'elecrix_modify_comment_form_fields' );

// comment Move Field
function elecrix_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'elecrix_move_comment_field_to_bottom' );


/**
 * Comment List Modification
 */

function elecrix_comments( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;?>

	<li  <?php comment_class('comment');?> id="comment-<?php comment_ID()?>">
        <div class="comment_element d-flex position-relative">
            <?php if ( get_avatar( $comment ) ) {?>
                <div class="comment_img">
                    <?php echo get_avatar( $comment, 90 ); ?>
                </div>
            <?php }?>

            <div class="comment_content pera-content">
                <h4 class="name"><?php comment_author_link()?></h4>
				<span class="comment-date"><?php echo esc_html(get_the_time( get_option('date_format')));?></span>
                <?php if ( $comment->comment_approved == '0' ): ?>
                    <p><em><?php esc_html_e( 'Your comment is awaiting moderation.', 'elecrix' );?></em></p>
                <?php endif;?>
                <?php comment_text();?>
                <div class="reply-btn position-absolute">
                	<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) );?>
                </div>
            </div>
        </div>
	</li>


<?php
}

/**
 * Search Widget
 */
function elecrix_search_widgets( $form ) {
    $form = '<div class="search-widget"><form role="search" method="get" id="searchform" class="searchform" action="' . home_url( '/' ) . '" >
    <input class="form_control" placeholder="' .esc_attr__( 'Type Keywords', 'elecrix' ) . '" type="text"  value="' . get_search_query() . '" name="s" id="s" />
    <button type="submit"><i class="far fa-search"></i></button>
    </form></div>';

    return $form;
}
add_filter( 'get_search_form', 'elecrix_search_widgets', 100 );

/**
 * post Pagination
 */
function elecrix_pagination() {
    global $wp_query;
    $links = paginate_links( array(
		'current'   => max( 1, get_query_var( 'paged' ) ),
		'total'     => $wp_query->max_num_pages,
		'type'      => 'list',
		'mid_size'  => 3,
		'prev_text' => '<i class="far fa-long-arrow-left"></i>',
		'next_text' => '<i class="far fa-long-arrow-right"></i>',
    ) );

    echo wp_kses_post( $links );
}

/**
 * Breadcrumb
 *
 * @return  [type]  [return description]
 */
function elecrix_the_breadcrumb() {
	global $wp_query;
	$queried_object = get_queried_object();
	$breadcrumb     = '';
	$delimiter      = '';
	$before         = '<li>';
	$after          = '</li>';
	if ( ! is_front_page() ) {
		$breadcrumb .= $before . '<a href="' . home_url( '/' ) . '">' . esc_html__( 'Home', 'elecrix' ) . ' &nbsp;</a>' . $after;
		/** If category or single post */
		if ( is_category() ) {
			$cat_obj       = $wp_query->get_queried_object();
			$this_category = get_category( $cat_obj->term_id );
			if ( $this_category->parent != 0 ) {
				$parent_category = get_category( $this_category->parent );
				$breadcrumb      .= get_category_parents( $parent_category, true, $delimiter );
			}
			$breadcrumb .= $before . '<a href="' . get_category_link( get_query_var( 'cat' ) ) . '">' . single_cat_title( '', false ) . '</a>' . $after;
		} elseif ( $wp_query->is_posts_page ) {
			$breadcrumb .= $before . $queried_object->post_title . $after;
		} elseif ( is_tax() ) {
			$breadcrumb .= $before . '<a href="' . get_term_link( $queried_object ) . '">' . $queried_object->name . '</a>' . $after;
		} elseif ( is_page() ) /** If WP pages */ {
			global $post;
			if ( $post->post_parent ) {
				$anc = get_post_ancestors( $post->ID );
				foreach ( $anc as $ancestor ) {
					$breadcrumb .= $before . '<a href="' . get_permalink( $ancestor ) . '">' . get_the_title( $ancestor ) . ' &nbsp;</a>' . $after;
				}
				$breadcrumb .= $before . '' . get_the_title( $post->ID ) . '' . $after;
			} else {
				$breadcrumb .= $before . '' . get_the_title() . '' . $after;
			}
		} elseif ( is_singular() ) {
			if ( $category = wp_get_object_terms( get_the_ID(), array( 'category', 'location', 'tax_feature' ) ) ) {
				if ( ! is_wp_error( $category ) ) {
					$breadcrumb .= $before . '<a href="' . get_term_link( elecrix_set( $category, '0' ) ) . '">' . elecrix_set( elecrix_set( $category, '0' ), 'name' ) . '&nbsp;</a>' . $after;
					$breadcrumb .= $before . '' . get_the_title() . '' . $after;
				} else {
					$breadcrumb .= $before . '' . get_the_title() . '' . $after;
				}
			} else {
				$breadcrumb .= $before . '' . get_the_title() . '' . $after;
			}
		} elseif ( is_tag() ) {
			$breadcrumb .= $before . '<a href="' . get_term_link( $queried_object ) . '">' . single_tag_title( '', false ) . '</a>' . $after;
		} /**If tag template*/
		elseif ( is_day() ) {
			$breadcrumb .= $before . '<a href="#">' . esc_html__( 'Archive for ', 'elecrix' ) . get_the_time( 'F jS, Y' ) . '</a>' . $after;
		} /** If daily Archives */
		elseif ( is_month() ) {
			$breadcrumb .= $before . '<a href="' . get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ) . '">' . __( 'Archive for ', 'elecrix' ) . get_the_time( 'F, Y' ) . '</a>' . $after;
		} /** If montly Archives */
		elseif ( is_year() ) {
			$breadcrumb .= $before . '<a href="' . get_year_link( get_the_time( 'Y' ) ) . '">' . __( 'Archive for ', 'elecrix' ) . get_the_time( 'Y' ) . '</a>' . $after;
		} /** If year Archives */
		elseif ( is_author() ) {
			$breadcrumb .= $before . '<a href="' . esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ) . '">' . __( 'Archive for ', 'elecrix' ) . get_the_author() . '</a>' . $after;
		} /** If author Archives */
		elseif ( is_search() ) {
			$breadcrumb .= $before . '' . esc_html__( 'Search Results for ', 'elecrix' ) . get_search_query() . '' . $after;
		} /** if search template */
		elseif ( is_404() ) {
			$breadcrumb .= $before . '' . esc_html__( '404 - Not Found', 'elecrix' ) . '' . $after;
			/** if search template */
		} elseif ( is_post_type_archive( 'product' ) ) {
			$shop_page_id = wc_get_page_id( 'shop' );
			if ( get_option( 'page_on_front' ) !== $shop_page_id ) {
				$shop_page = get_post( $shop_page_id );
				$_name     = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';
				if ( ! $_name ) {
					$product_post_type = get_post_type_object( 'product' );
					$_name             = $product_post_type->labels->singular_name;
				}
				if ( is_search() ) {
					$breadcrumb .= $before . '<a href="' . get_post_type_archive_link( 'product' ) . '">' . $_name . '</a>' . $delimiter . esc_html__( 'Search results for &ldquo;', 'elecrix' ) . get_search_query() . '&rdquo;' . $after;
				} elseif ( is_paged() ) {
					$breadcrumb .= $before . '<a href="' . get_post_type_archive_link( 'product' ) . '">' . $_name . '</a>' . $after;
				} else {
					$breadcrumb .= $before . $_name . $after;
				}
			}
		} else {
			$breadcrumb .= $before . '<a href="' . get_permalink() . '">' . wp_title() . '</a>' . $after;
		}
		/** Default value */
	}

	return $breadcrumb;
}


/**
 * Category Count Markup
 */
function elecrix_category_html( $links ) {
    $links = str_replace( '</a> (', '<span class="number">', $links );
    $links = str_replace( ')', '</span></a>', $links );
    return $links;
}
add_filter( 'wp_list_categories', 'elecrix_category_html' );

/**
 * Archive Count Markup
 */
function elecrix_archive_html($links) {
    $links = str_replace('</a>&nbsp;(', '<span class="number">', $links);
    $links = str_replace(')', '</span></a>', $links);
    return $links;
}

add_filter('get_archives_link', 'elecrix_archive_html');

function bizex_product_count( $cols ) {
	$product_count = cs_get_option('product_count');
  $cols = !empty($product_count) ? $product_count : '12';
  return $cols;
}
add_filter( 'loop_shop_per_page', 'bizex_product_count', 20 );